==> fap-0.10.0.tar.bz2: fap-0.10.0/src/gui/settings.cpp <==
/*
 *  Copyright (C) 2008-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "settings.h"
#include "iconFactory.h"
#include "audio.h"
#include "input.h"

FXDEFMAP(settingsWindow) settingsWindowMap[] = {
	// Message_Type		ID			Message_Handler
	FXMAPFUNC(SEL_COMMAND,	settingsWindow::ID_COLOR,	settingsWindow::onCmdColor),
	FXMAPFUNC(SEL_COMMAND,	settingsWindow::ID_REPLAYGAIN,	settingsWindow::onCmdReplayGain),
};

FXIMPLEMENT(settingsWindow, FXDialogBox, settingsWindowMap, ARRAYNUMBER(settingsWindowMap))

settingsWindow::settingsWindow(FXWindow* win, inputConfig* i) :
	FXDialogBox(win, FXString::null, DECOR_TITLE|DECOR_BORDER, 0,0,0,0, 0,0,0,0) {

	setTitle(tr("Settings"));

	_subtunes.connect(SETTINGS->_subtunes);
	_autoBk.connect(SETTINGS->_autoBk);
	_albumArtQuality.connect(SETTINGS->_albumArtQuality);
	_replayGainMode.connect(SETTINGS->_replayGainMode);

#ifdef HAVE_BS2B
	_bs2b.connect(SETTINGS->_bs2b);
#endif

	FXVerticalFrame* main=new FXVerticalFrame(this, LAYOUT_FILL_X);

	FXHorizontalFrame *horizontal=new FXHorizontalFrame(main, LAYOUT_FILL);
	FXVerticalFrame *buttons=new FXVerticalFrame(horizontal, LAYOUT_LEFT|LAYOUT_FILL_Y|FRAME_SUNKEN|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT, 0,0,0,0, 0,0,0,0, 0,0);
	FXSwitcher *switcher=new FXSwitcher(horizontal, LAYOUT_FILL, 0,0,0,0, 0,0,0,0);

	// General settings
	FXVerticalFrame* optionpane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(optionpane, tr("General settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(optionpane, SEPARATOR_LINE|LAYOUT_FILL_X);

	new FXCheckButton(optionpane, tr("&Play subtunes\tPlay all subtunes"), &_subtunes, FXDataTarget::ID_VALUE);
	new FXCheckButton(optionpane, tr("&Auto backend\tAutomatic backend selection"), &_autoBk, FXDataTarget::ID_VALUE);
#ifdef HAVE_BS2B
	new FXCheckButton(optionpane, tr("Bauer stereophonic-to-binaural DSP"), &_bs2b, FXDataTarget::ID_VALUE);
#endif

	new FXCheckButton(optionpane, tr("Album art HQ resizing\tHigh quality album art resizing"),
		&_albumArtQuality, FXDataTarget::ID_VALUE);

	FXCheckButton *rg=new FXCheckButton(optionpane, tr("Replaygain\tEnable replaygain loudness normalization"), this, settingsWindow::ID_REPLAYGAIN);
	rg->setCheck(SETTINGS->_replayGain);

	_replayGainBox=new FXVerticalFrame(optionpane, LAYOUT_FILL_X, 0,0,0,0, 16,0,0,0, 0,0);
	new FXRadioButton(_replayGainBox, tr("Album gain\tPreserve album dynamics"), &_replayGainMode, FXDataTarget::ID_OPTION, RADIOBUTTON_NORMAL);
	new FXRadioButton(_replayGainBox, tr("Track gain\tAll tracks equal loudness"), &_replayGainMode, FXDataTarget::ID_OPTION+1, RADIOBUTTON_NORMAL);
	enableControls(_replayGainBox, SETTINGS->_replayGain);

	new FXButton(buttons, tr("General\tGeneral settings\tGeneral settings"), GET_ICON(icon_preferencesdesktop), switcher, FXSwitcher::ID_OPEN_FIRST, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Interface settings
	FXVerticalFrame* interfacepane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(interfacepane, tr("Interface settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(interfacepane, SEPARATOR_LINE|LAYOUT_FILL_X);

	FXMatrix *matrix=new FXMatrix(interfacepane, 2, MATRIX_BY_COLUMNS|LAYOUT_FILL);
	new FXLabel(matrix, tr("Alt. color\tAlternate color for lists"));
	new FXColorWell(matrix, SETTINGS->_altCol, this, settingsWindow::ID_COLOR,
		COLORWELL_OPAQUEONLY|COLORWELL_NORMAL|LAYOUT_RIGHT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL,
		0, 0, 40, 24);

	new FXButton(buttons,tr("Interface\tInterface settings\tInterface settings"), GET_ICON(icon_guioptions), switcher, FXSwitcher::ID_OPEN_SECOND, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Audio settings
	FXVerticalFrame* audiopane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(audiopane, tr("Audio settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(audiopane, SEPARATOR_LINE|LAYOUT_FILL_X);

	new audioConfig(audiopane);

	new FXButton(buttons, tr("Audio\tAudio settings\tAudio settings"), GET_ICON(icon_card), switcher, FXSwitcher::ID_OPEN_THIRD, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Backend settings
	FXVerticalFrame* backendpane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(backendpane, tr("Backend settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(backendpane, SEPARATOR_LINE|LAYOUT_FILL_X);

	i->config(backendpane);

	new FXButton(buttons, tr("Backend\tBackend settings\tBackend settings"), i->icon(), switcher, FXSwitcher::ID_OPEN_FOURTH, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	new FXSeparator(this);

	FXHorizontalFrame* bottom=new FXHorizontalFrame(this, LAYOUT_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH);
	FXButton* initial=new FXButton(bottom, tr("&OK"), GET_ICON(icon_dialogok),
		this, ID_ACCEPT, BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X);
	new FXButton(bottom, tr("&Cancel"), GET_ICON(icon_dialogcancel),
		this, ID_CANCEL, BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X);
	initial->setFocus();
}

void settingsWindow::enableControls(FXPacker* p, const FXbool enable) {

	if (enable) {
		for (FXWindow *obj=p->getFirst(); obj; obj=obj->getNext())
			obj->enable();
	} else {
		for (FXWindow *obj=p->getFirst(); obj; obj=obj->getNext())
			obj->disable();
	}
}

long settingsWindow::onCmdColor(FXObject*, FXSelector, void* ptr) {

	SETTINGS->_altCol=(FXColor)(FXuval)ptr;
	return 1;
}

long settingsWindow::onCmdReplayGain(FXObject*, FXSelector, void* ptr) {

	SETTINGS->_replayGain=(FXbool)(FXuval)ptr;
	enableControls(_replayGainBox, SETTINGS->_replayGain);

	return 1;
}

/*****************************************************************/

settings* SETTINGS {

	static settings s;
	return &s;
}

void settings::load() {

	_apiName=FXApp::instance()->reg().readStringEntry("Audio Settings", "api");
	_card=FXApp::instance()->reg().readStringEntry("Audio Settings", "card");
	_bits=FXApp::instance()->reg().readIntEntry("Audio Settings", "bits", 16);

	_subtunes=FXApp::instance()->reg().readBoolEntry("General Settings", "play subtunes", FALSE);
	_autoBk=FXApp::instance()->reg().readBoolEntry("General Settings", "auto backend", TRUE);
	_altCol=FXApp::instance()->reg().readColorEntry("General Settings", "alternate color", -1);
	_replayGain=FXApp::instance()->reg().readBoolEntry("General Settings", "Replaygain", FALSE);
	FXString replayGainMode=FXApp::instance()->reg().readStringEntry("General Settings", "Replaygain mode", "Album");
	_replayGainMode=(!comparecase(replayGainMode, "Track"))?1:0;

#ifdef HAVE_BS2B
	_bs2b=FXApp::instance()->reg().readBoolEntry("General Settings", "Bauer DSP", FALSE);
#endif
	_albumArtQuality=FXApp::instance()->reg().readBoolEntry("General Settings", "album art quality", TRUE);
}

void settings::save() {

	FXApp::instance()->reg().writeStringEntry("Audio Settings", "api", _apiName.text());
	FXApp::instance()->reg().writeStringEntry("Audio Settings", "card", _card.text());
	FXApp::instance()->reg().writeIntEntry("Audio Settings", "bits", _bits);

	FXApp::instance()->reg().writeBoolEntry("General Settings", "play subtunes", _subtunes);
	FXApp::instance()->reg().writeBoolEntry("General Settings", "auto backend", _autoBk);
	FXApp::instance()->reg().writeColorEntry("General Settings", "alternate color", _altCol);
	FXApp::instance()->reg().writeBoolEntry("General Settings", "Replaygain", _replayGain);
	FXApp::instance()->reg().writeStringEntry("General Settings", "Replaygain mode", _replayGainMode==0?"Album":"Track");
#ifdef HAVE_BS2B
	FXApp::instance()->reg().writeBoolEntry("General Settings", "Bauer DSP", _bs2b);
#endif
	FXApp::instance()->reg().writeBoolEntry("General Settings", "album art quality", _albumArtQuality);
}

==> fap-0.11.1.tar.bz2: fap-0.11.1/src/gui/settings.cpp <==
/*
 *  Copyright (C) 2008-2015 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "settings.h"

#include "iconFactory.h"
#include "audio.h"
#include "input/input.h"
#include "output/outputFactory.h"

FXDEFMAP(settingsWindow) settingsWindowMap[] = {
	// Message_Type		ID			Message_Handler
	FXMAPFUNC(SEL_COMMAND,	settingsWindow::ID_COLOR,	settingsWindow::onCmdColor),
	FXMAPFUNC(SEL_COMMAND,	settingsWindow::ID_REPLAYGAIN,	settingsWindow::onCmdReplayGain),
};

FXIMPLEMENT(settingsWindow, FXDialogBox, settingsWindowMap, ARRAYNUMBER(settingsWindowMap))

settingsWindow::settingsWindow(FXWindow* win, inputConfig* i) :
	FXDialogBox(win, FXString::null, DECOR_TITLE|DECOR_BORDER, 0,0,0,0, 0,0,0,0) {

	setTitle(tr("Settings"));

	_subtunes.connect(SETTINGS->_subtunes);
	_autoBk.connect(SETTINGS->_autoBk);
	_albumArtQuality.connect(SETTINGS->_albumArtQuality);
	_replayGainMode.connect(SETTINGS->_replayGainMode);

#ifdef HAVE_BS2B
	_bs2b.connect(SETTINGS->_bs2b);
#endif

	FXVerticalFrame* main=new FXVerticalFrame(this, LAYOUT_FILL_X);

	FXHorizontalFrame *horizontal=new FXHorizontalFrame(main, LAYOUT_FILL);
	FXVerticalFrame *buttons=new FXVerticalFrame(horizontal, LAYOUT_LEFT|LAYOUT_FILL_Y|FRAME_SUNKEN|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT, 0,0,0,0, 0,0,0,0, 0,0);
	FXSwitcher *switcher=new FXSwitcher(horizontal, LAYOUT_FILL, 0,0,0,0, 0,0,0,0);

	// General settings
	FXVerticalFrame* optionpane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(optionpane, tr("General settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(optionpane, SEPARATOR_LINE|LAYOUT_FILL_X);

	new FXCheckButton(optionpane, tr("&Play subtunes\tPlay all subtunes"), &_subtunes, FXDataTarget::ID_VALUE);
	new FXCheckButton(optionpane, tr("&Auto backend\tAutomatic backend selection"), &_autoBk, FXDataTarget::ID_VALUE);
#ifdef HAVE_BS2B
	new FXCheckButton(optionpane, tr("Bauer stereophonic-to-binaural DSP"), &_bs2b, FXDataTarget::ID_VALUE);
#endif

	new FXCheckButton(optionpane, tr("Album art HQ resizing\tHigh quality album art resizing"),
		&_albumArtQuality, FXDataTarget::ID_VALUE);

	FXCheckButton *rg=new FXCheckButton(optionpane, tr("Replaygain\tEnable replaygain loudness normalization"), this, settingsWindow::ID_REPLAYGAIN);
	rg->setCheck(SETTINGS->_replayGain);

	_replayGainBox=new FXVerticalFrame(optionpane, LAYOUT_FILL_X, 0,0,0,0, 16,0,0,0, 0,0);
	new FXRadioButton(_replayGainBox, tr("Album gain\tPreserve album dynamics"), &_replayGainMode, FXDataTarget::ID_OPTION, RADIOBUTTON_NORMAL);
	new FXRadioButton(_replayGainBox, tr("Track gain\tAll tracks equal loudness"), &_replayGainMode, FXDataTarget::ID_OPTION+1, RADIOBUTTON_NORMAL);
	enableControls(_replayGainBox, SETTINGS->_replayGain);

	new FXButton(buttons, tr("General\tGeneral settings\tGeneral settings"), GET_ICON(icon_preferencesdesktop), switcher, FXSwitcher::ID_OPEN_FIRST, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Interface settings
	FXVerticalFrame* interfacepane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(interfacepane, tr("Interface settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(interfacepane, SEPARATOR_LINE|LAYOUT_FILL_X);

	FXMatrix *matrix=new FXMatrix(interfacepane, 2, MATRIX_BY_COLUMNS|LAYOUT_FILL);
	new FXLabel(matrix, tr("Alt. color\tAlternate color for lists"));
	new FXColorWell(matrix, SETTINGS->_altCol, this, settingsWindow::ID_COLOR,
		COLORWELL_OPAQUEONLY|COLORWELL_NORMAL|LAYOUT_RIGHT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL,
		0, 0, 40, 24);

	new FXButton(buttons,tr("Interface\tInterface settings\tInterface settings"), GET_ICON(icon_guioptions), switcher, FXSwitcher::ID_OPEN_SECOND, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Audio settings
	FXVerticalFrame* audiopane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(audiopane, tr("Audio settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(audiopane, SEPARATOR_LINE|LAYOUT_FILL_X);

	new audioConfig(audiopane);

	new FXButton(buttons, tr("Audio\tAudio settings\tAudio settings"), GET_ICON(icon_card), switcher, FXSwitcher::ID_OPEN_THIRD, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	// Backend settings
	FXVerticalFrame* backendpane=new FXVerticalFrame(switcher, LAYOUT_FILL, 0,0,0,0, 0,0,0,0, 0,0);
	new FXLabel(backendpane, tr("Backend settings"), 0, LAYOUT_LEFT);
	new FXHorizontalSeparator(backendpane, SEPARATOR_LINE|LAYOUT_FILL_X);

	i->config(backendpane);

	new FXButton(buttons, tr("Backend\tBackend settings\tBackend settings"), i->icon(), switcher, FXSwitcher::ID_OPEN_FOURTH, FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL_Y);

	new FXSeparator(this);

	FXHorizontalFrame* bottom=new FXHorizontalFrame(this, LAYOUT_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH);
	FXButton* initial=new FXButton(bottom, tr("&OK"), GET_ICON(icon_dialogok),
		this, ID_ACCEPT, BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X);
	new FXButton(bottom, tr("&Cancel"), GET_ICON(icon_dialogcancel),
		this, ID_CANCEL, BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X);
	initial->setFocus();
}

void settingsWindow::enableControls(FXPacker* p, const FXbool enable) {

	if (enable) {
		for (FXWindow *obj=p->getFirst(); obj; obj=obj->getNext())
			obj->enable();
	} else {
		for (FXWindow *obj=p->getFirst(); obj; obj=obj->getNext())
			obj->disable();
	}
}

long settingsWindow::onCmdColor(FXObject*, FXSelector, void* ptr) {

	SETTINGS->_altCol=(FXColor)(FXuval)ptr;
	return 1;
}

long settingsWindow::onCmdReplayGain(FXObject*, FXSelector, void* ptr) {

	SETTINGS->_replayGain=(FXbool)(FXuval)ptr;
	enableControls(_replayGainBox, SETTINGS->_replayGain);

	return 1;
}

/*****************************************************************/

settings* SETTINGS {

	static settings s;
	return &s;
}

void settings::load() {

	_apiName=FXApp::instance()->reg().readStringEntry("Audio Settings", "api", OFACTORY->name(0));
	_card=FXApp::instance()->reg().readStringEntry("Audio Settings", "card");
	_bits=FXApp::instance()->reg().readIntEntry("Audio Settings", "bits", 16);

	_subtunes=FXApp::instance()->reg().readBoolEntry("General Settings", "play subtunes", FALSE);
	_autoBk=FXApp::instance()->reg().readBoolEntry("General Settings", "auto backend", TRUE);
	_altCol=FXApp::instance()->reg().readColorEntry("General Settings", "alternate color", -1);
	_replayGain=FXApp::instance()->reg().readBoolEntry("General Settings", "Replaygain", FALSE);
	FXString replayGainMode=FXApp::instance()->reg().readStringEntry("General Settings", "Replaygain mode", "Album");
	_replayGainMode=(!comparecase(replayGainMode, "Track"))?1:0;

#ifdef HAVE_BS2B
	_bs2b=FXApp::instance()->reg().readBoolEntry("General Settings", "Bauer DSP", FALSE);
#endif
	_albumArtQuality=FXApp::instance()->reg().readBoolEntry("General Settings", "album art quality", TRUE);
}

void settings::save() {

	FXApp::instance()->reg().writeStringEntry("Audio Settings", "api", _apiName.text());
	FXApp::instance()->reg().writeStringEntry("Audio Settings", "card", _card.text());
	FXApp::instance()->reg().writeIntEntry("Audio Settings", "bits", _bits);

	FXApp::instance()->reg().writeBoolEntry("General Settings", "play subtunes", _subtunes);
	FXApp::instance()->reg().writeBoolEntry("General Settings", "auto backend", _autoBk);
	FXApp::instance()->reg().writeColorEntry("General Settings", "alternate color", _altCol);
	FXApp::instance()->reg().writeBoolEntry("General Settings", "Replaygain", _replayGain);
	FXApp::instance()->reg().writeStringEntry("General Settings", "Replaygain mode", _replayGainMode==0?"Album":"Track");
#ifdef HAVE_BS2B
	FXApp::instance()->reg().writeBoolEntry("General Settings", "Bauer DSP", _bs2b);
#endif
	FXApp::instance()->reg().writeBoolEntry("General Settings", "album art quality", _albumArtQuality);
}
